@@ -1,4 +1,4 @@
-/* $Id: mag.c,v 1.1.1.1 2007/03/16 17:16:14 dk Exp $ */
+/* $Id: mag.c,v 1.1 2007/03/16 17:16:14 dk Exp $ */
 
 #ifdef __cplusplus
 extern "C" {
@@ -14,7 +14,11 @@ void magick_croak( char * what, ExceptionInfo * exception )
 {
         char message[MaxTextExtent] = "unknown exception";
         if ((exception)->severity != UndefinedException)
+#if MagickLibVersion > 0x676
+                FormatLocaleString( 
+#else
                 FormatMagickString( 
+#endif
                         message, 
                         MaxTextExtent,
                         "Exception %d: %s%s%s%s",
